@@ -1,7 +1,7 @@
 package Mojar::Google::Analytics;
 use Mojo::Base -base;
 
-our $VERSION = 1.101;
+our $VERSION = 1.111;
 
 use 5.014;  # For MIME::Base64::encode_base64url
 use Carp 'croak';
@@ -112,9 +112,9 @@ sub _request_token {
   else {
     my $ga_res = Mojar::Google::Analytics::Response->new;
     $ga_res->parse($res);
-    my $code = $ga_res->error->{code} || 'Connection';
+    my $code = $ga_res->code || 'Connection';
     croak sprintf '%s error: %s',
-        $ga_res->error->{code} || 'Connection', $ga_res->error->{message};
+        $ga_res->code || 'Connection', $ga_res->message;
   }
 }
 
